@@ -113,8 +113,7 @@ class QPImage(object):
             for key in holo_kw:
                 if key == "sideband":
                     if holo_kw[key] in [-1, 1]:
-                        qpretrieve_kw["sideband_freq"] = None
-                        qpretrieve_kw["invert_phase"] = holo_kw[key] == 1
+                        qpretrieve_kw["invert_phase"] = holo_kw[key] == -1
                     else:
                         qpretrieve_kw["sideband_freq"] = holo_kw[key]
                         qpretrieve_kw["invert_phase"] = False
